from setuptools import setup, find_packages

setup(
    name='rldev',
    packages=find_packages(),
    version='0.0.1',
    author='Zhang Dongkun',
    author_email='zhangdongkun98@gmail.com',
    url='https://github.com/zhangdongkun98/rl-dev',
    description='Kit for RL.',
    install_requires=[
    ],

    include_package_data=True
)
